@@ -1,6 +1,7 @@
 from alliancepy.client import Client
 from alliancepy.season import Season
 from alliancepy.match_type import MatchType
+import logging
 
 # MIT License
 #
@@ -24,4 +25,15 @@ from alliancepy.match_type import MatchType
 # OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 # SOFTWARE.
 
-__version__ = "1.4.1"
+__version__ = "1.4.4"
+
+try:
+    from logging import NullHandler
+except ImportError:
+
+    class NullHandler(logging.Handler):
+        def emit(self, record):
+            pass
+
+
+logging.getLogger(__name__).addHandler(NullHandler())
