@@ -4,6 +4,7 @@ from alliancepy.season import Season
 from alliancepy.match_type import MatchType
 import asyncio
 import re
+import logging
 
 # MIT License
 #
@@ -27,6 +28,8 @@ import re
 # OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 # SOFTWARE.
 
+logger = logging.getLogger(__name__)
+
 
 class Event:
     """
@@ -63,6 +66,9 @@ class Event:
         location = f"{info['city']} {info['state_prov']}, {info['country']}"
         self.location = location
         self.venue = info["venue"]
+        logger.info(
+            f"Initialized asynchronous 'Event' object with event key of {self._event_key}"
+        )
 
     def __str__(self):
         return f"<Event: {self.name}>"
@@ -74,13 +80,16 @@ class Event:
         """
         Get one of the matches for the event.
 
-        :param match_type: The type of the match. See :ref:`match_type` for more information.
-        :type match_type: :class:`~alliancepy.match_type.MatchType`
-        :param match_number: The number of the match.
-        :type match_number: int
-        :return: A :class:`~.async_match.Match` object containing details about the specific match.
-        :rtype: :class:`.async_match.Match`
+        Args:
+            match_type (:class:`~alliancepy.match_type.MatchType`): The type of the match. See :ref:`match_type` for \
+            more information.
+            match_number (int): The number of the match.
+        Return:
+            :class:`.async_match.Match`: A :class:`~.async_match.Match` object containing details about the \
+            specific match.
         """
+        log_str = f"Got request to create asynchronous Match object with type {match_type} and number of {match_number}"
+        logger.info(log_str)
         if len(str(match_number)) == 1:
             match_name = f"{match_type.value}00{match_number}"
         elif len(str(match_number)) == 2:
@@ -94,19 +103,24 @@ class Event:
         mdict = {}
         for match in matches:
             key = match["match_key"]
+            logger.info(f"Processing match key {key}")
             key_right_strip = re.sub(r"\d{4}-\w+-\w+-", "", key)
             value = re.sub(r"-\d+", "", key_right_strip)
             mdict[key] = value
         try:
+            logger.info("Performing reverse lookup of match key")
             match_key = list(mdict.keys())[
                 list(mdict.values()).index(match_name.upper())
             ]
         except ValueError:
+            logger.error(f"This match does not exist!")
             raise ValueError("This match does not exist")
         else:
+            logger.info(f"Sucessfully fetched match key, returning Match object")
             return Match(match_key, headers=self._headers)
 
     async def _rankings(self):
+        logger.info("Getting rankings data...")
         resp = await request(
             f"/event/{self._event_key}/rankings", headers=self._headers
         )
@@ -116,10 +130,10 @@ class Event:
         """
         The specified team's rank at the end of the match.
 
-        :param team_number: A valid FTC team number.
-        :type team_number: int
-        :return: The rank as an integer
-        :rtype: int
+        Args:
+            team_number (int): A valid FTC team number.
+        Return:
+            int: The rank as an integer.
         """
         rankings = await self._rankings()
         for rank in rankings:
@@ -131,10 +145,10 @@ class Event:
         """
         The amount of times the team's rank changed during the event.
 
-        :param team_number: A valid FTC team number.
-        :type team_number: int
-        :return: The rank change as an integer
-        :rtype: int
+        Args:
+            team_number (int): A valid FTC team number.
+        Return:
+            int: The rank change as an integer.
         """
         rankings = await self._rankings()
         for rank in rankings:
@@ -146,10 +160,10 @@ class Event:
         """
         The amount of times within the event that the specified team won a match.
 
-        :param team_number: A valid FTC team number.
-        :type team_number: int
-        :return: The amount of wins as an integer
-        :rtype: int
+        Args:
+            team_number (int): A valid FTC team number.
+        Return:
+            int: The amount of wins as an integer.
         """
         rankings = await self._rankings()
         for rank in rankings:
@@ -161,10 +175,10 @@ class Event:
         """
         The amount of times within the event that the specified team lost a match.
 
-        :param team_number: A valid FTC team number.
-        :type team_number: int
-        :return: The amount of losses as an integer
-        :rtype: int
+        Args:
+            team_number (int): A valid FTC team number.
+        Return:
+            int: The amount of losses as an integer.
         """
         rankings = await self._rankings()
         for rank in rankings:
@@ -176,10 +190,10 @@ class Event:
         """
         The amount of times within the event that the specified team tied in a match.
 
-        :param team_number: A valid FTC team number.
-        :type team_number: int
-        :return: The amount of ties as an integer
-        :rtype: int
+        Args:
+            team_number (int): A valid FTC team number.
+        Return:
+            int: The amount of ties as an integer.
         """
         rankings = await self._rankings()
         for rank in rankings:
@@ -191,10 +205,10 @@ class Event:
         """
         The specified team's OPR for this event only. Penalties are factored in.
 
-        :param team_number: A valid FTC team number.
-        :type team_number: int
-        :return: The OPR as a floating point number.
-        :rtype: float
+        Args:
+            team_number (int): A valid FTC team number.
+        Return:
+            float: The OPR as a floating point number.
         """
         rankings = await self._rankings()
         for rank in rankings:
@@ -206,10 +220,10 @@ class Event:
         """
         The specified team's OPR for this event only. Penaltied are not factored in.
 
-        :param team_number: A valid FTC team number.
-        :type team_number: int
-        :return: The NP_OPR as a floating point number.
-        :rtype: float
+        Args:
+            team_number (int): A valid FTC team number.
+        Return:
+            float: The NP_OPR as a floating point number.
         """
         rankings = await self._rankings()
         for rank in rankings:
@@ -221,10 +235,10 @@ class Event:
         """
         The specified team's highest score in a qualifier.
 
-        :param team_number: A valid FTC team number.
-        :type team_number: int
-        :return: The score as an integer
-        :rtype: int
+        Args:
+            team_number (int): A valid FTC team number.
+        Return:
+            int: The score as an integer.
         """
         rankings = await self._rankings()
         for rank in rankings:
@@ -236,10 +250,10 @@ class Event:
         """
         The specified team's ranking points for this event only.
 
-        :param team_number: A valid FTC team number.
-        :type team_number: int
-        :return: The amount of ranking points as a floating point number
-        :rtype: float
+        Args:
+            team_number (int): A valid FTC team number.
+        Return:
+            float: The amount of ranking points as a floating point number.
         """
         rankings = await self._rankings()
         for rank in rankings:
@@ -251,10 +265,10 @@ class Event:
         """
         The specified team's qualifying points for this event only.
 
-        :param team_number: A valid FTC team number.
-        :type team_number: int
-        :return: The amount of qualifying points as an integer
-        :rtype: int
+        Args:
+            team_number (int): A valid FTC team number.
+        Return:
+            int: The amount of wualifying points as an integer.
         """
         rankings = await self._rankings()
         for rank in rankings:
@@ -266,10 +280,10 @@ class Event:
         """
         The specified team's tiebreaker points for this event only.
 
-        :param team_number: A valid FTC team number.
-        :type team_number: int
-        :return: The amount of tiebreaker points as a floating point number
-        :rtype: int
+        Args:
+            team_number (int): A valid FTC team number.
+        Return:
+            float: The amount of tiebreaker points as a floating point number.
         """
         rankings = await self._rankings()
         for rank in rankings:
